@@ -980,7 +980,7 @@ class Submission(Editable, Hideable, Moderatable, Refreshable, Reportable,
         """Sticky a post in its subreddit.
 
         If there is already a stickied post in the concerned subreddit then it
-        will be unstickied.
+        will be unstickied. Only self submissions can be stickied.
 
         :returns: The json response from the server
 
@@ -1139,6 +1139,9 @@ class Subreddit(Messageable, Refreshable):
         base = (reddit_session.config['subreddit'] % self.display_name)
         self._listing_urls = [base + x + '.json' for x in listings]
 
+    def __repr__(self):
+        return 'Subreddit(display_name=\'{0}\')'.format(self.display_name)
+
     def __unicode__(self):
         return self.display_name
 
